"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.default = void 0;

var _react = _interopRequireWildcard(require("react"));

var _ui = require("@runly/ui");

var _retry = _interopRequireDefault(require("./retry"));

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

function _getRequireWildcardCache() { if (typeof WeakMap !== "function") return null; var cache = new WeakMap(); _getRequireWildcardCache = function () { return cache; }; return cache; }

function _interopRequireWildcard(obj) { if (obj && obj.__esModule) { return obj; } if (obj === null || typeof obj !== "object" && typeof obj !== "function") { return { default: obj }; } var cache = _getRequireWildcardCache(); if (cache && cache.has(obj)) { return cache.get(obj); } var newObj = {}; var hasPropertyDescriptor = Object.defineProperty && Object.getOwnPropertyDescriptor; for (var key in obj) { if (Object.prototype.hasOwnProperty.call(obj, key)) { var desc = hasPropertyDescriptor ? Object.getOwnPropertyDescriptor(obj, key) : null; if (desc && (desc.get || desc.set)) { Object.defineProperty(newObj, key, desc); } else { newObj[key] = obj[key]; } } } newObj.default = obj; if (cache) { cache.set(obj, newObj); } return newObj; }

const RunProgress = ({
  org,
  runId,
  allowRetry = false
}) => {
  const [retryRunId, setRetryRunId] = (0, _react.useState)();
  const onRequeued = (0, _react.useCallback)(r => setRetryRunId(r.id), []);
  const {
    run
  } = (0, _ui.useRunConnection)(org, retryRunId || runId);

  if (!run) {
    return /*#__PURE__*/_react.default.createElement(Indeterminant, null);
  }

  return /*#__PURE__*/_react.default.createElement(_react.default.Fragment, null, /*#__PURE__*/_react.default.createElement(ProgressBar, {
    isRunning: run.state == "Running",
    progress: run.progress
  }), /*#__PURE__*/_react.default.createElement(_ui.ProgressText, {
    progress: run.progress,
    component: "small",
    className: "text-muted"
  }), allowRetry ? /*#__PURE__*/_react.default.createElement("p", null, /*#__PURE__*/_react.default.createElement(_retry.default, {
    org,
    run,
    onRequeued
  })) : null);
};

const ProgressBar = ({
  isRunning,
  progress
}) => {
  if (isProgressEmpty(progress)) {
    return /*#__PURE__*/_react.default.createElement(Indeterminant, null);
  }

  const {
    success,
    failed,
    total
  } = progress;

  if (!total) {
    return /*#__PURE__*/_react.default.createElement(Indeterminant, {
      className: `${failed ? "bg-danger" : success ? "bg-success" : ""}`
    });
  }

  return /*#__PURE__*/_react.default.createElement("div", {
    className: "progress"
  }, /*#__PURE__*/_react.default.createElement(Progress, {
    isRunning: isRunning,
    isSuccess: true,
    value: success,
    total: total
  }), /*#__PURE__*/_react.default.createElement(Progress, {
    isRunning: isRunning,
    value: failed,
    total: total
  }));
};

const Indeterminant = ({
  className
}) => /*#__PURE__*/_react.default.createElement("div", {
  className: "progress"
}, /*#__PURE__*/_react.default.createElement("div", {
  className: `progress-bar progress-bar-striped progress-bar-animated ${className || ""}`,
  role: "progressbar",
  style: {
    width: "100%"
  }
}));

const Progress = ({
  isRunning,
  isSuccess,
  value,
  total
}) => {
  if (!value) return null;
  const percentage = value / total * 100.0;
  return /*#__PURE__*/_react.default.createElement("div", {
    className: `progress-bar ${isSuccess ? "bg-success" : "bg-danger"} ${isRunning ? "progress-bar-striped progress-bar-animated" : ""}`,
    role: "progressbar",
    style: {
      width: `${percentage}%`
    },
    "aria-valuenow": value,
    "aria-valuemin": value,
    "aria-valuemax": total
  });
};

function isProgressEmpty(progress) {
  if (!progress) return true;
  if (!progress.success && !progress.failed && !progress.total) return true;
  return false;
}

var _default = RunProgress;
exports.default = _default;